#
# spec file for package libtraceevent
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define sonum   1
%define dname   traceevent
%define soname  %{name}%{sonum}
%define sodname %{dname}%{sonum}

Name:           libtraceevent
Version:        1.8.3
Release:        1.1
Summary:        Linux kernel trace event library
License:        GPL-2.0-only AND LGPL-2.1-only
Group:          Development/Libraries/C and C++
URL:            https://git.kernel.org/pub/scm/libs/libtrace/libtraceevent.git/
Source:         https://git.kernel.org/pub/scm/libs/libtrace/%{name}.git/snapshot/%{name}-%{version}.tar.gz
Source9:        %name-rpmlintrc
BuildRequires:  asciidoc
BuildRequires:  fdupes
BuildRequires:  glibc-devel
BuildRequires:  meson
BuildRequires:  source-highlight
BuildRequires:  xmlto

%description
Linux kernel trace event library. This was once embedded in trace-cmd, but now it is its own standalone library.

%package -n %{soname}
Summary:        Linux kernel trace event library
License:        GPL-2.0-only
Group:          System/Libraries

%description -n %{soname}
The libtraceevent library provides APIs to access kernel tracepoint events located in the tracefs file system under the events directory.

%package -n %{soname}-plugins
Summary:        Plugins for the Linux kernel trace event library
License:        GPL-2.0-only AND LGPL-2.1-only
Group:          System/Libraries
Requires:       %{soname} = %{version}

%description -n %{soname}-plugins
This package provides plugins for the libtraceevent library.

%package devel
Summary:        Header files for %{name}
License:        GPL-2.0-only AND LGPL-2.1-only
Group:          Development/Libraries/C and C++
Requires:       %{soname} = %{version}

%description -n %{name}-devel
The package provides header and other needed development files for the library %{name}

%prep
%autosetup -p1

%build
export LDFLAGS="-ldl"

%meson \
    --default-library=shared \
    -Dhtmldir=%{_docdir}/%{name} \
    -Dplugindir=%{_libdir}/%{sodname}/plugins
%meson_build
%meson_build docs

%install
%meson_install

%fdupes %buildroot/%_prefix

ls -lR %{buildroot}/%{_libdir}

%post -n %{soname} -p /sbin/ldconfig
%postun -n %{soname} -p /sbin/ldconfig

%files -n %{soname}
%{_libdir}/%{name}.so.*

%files -n %{soname}-plugins
%dir %{_libdir}/%{sodname}
%dir %{_libdir}/%{sodname}/plugins
%{_libdir}/%{sodname}/plugins/*.so*
%{_libdir}/%{sodname}/plugins/libtraceevent-dynamic-list

%files devel
%dir %{_includedir}/%{dname}
%{_includedir}/%{dname}/*.h
%{_libdir}/%{name}.so
%{_libdir}/pkgconfig/%{name}.pc
%{_mandir}/man3/*
%{_docdir}/%{name}/

%changelog
* Sat Aug 31 2024 Dirk Müller <dmueller@suse.com>
- update to 1.8.3:
  * Fix a double free in process_op()
  * Do not return a local stack pointer in get_field_str()
  * prevent a memory leak in tep_plugin_add_option()
  * Prevent a memory leak in process_fields()
  * Close shared object in the error path of load_plugin()
  * Avoid a simple asprintf case
  * Fix event-parse memory leak in process_cond
  * Have single quotes represent characters
  * Fix tests running on big endian arch
* Mon Jun 17 2024 Daniel Wagner <daniel.wagner@suse.com>
- Update to 1.8.2
  * New APIs:
  - tep_record_is_event() - A helper function that basically converts
  int type= tep_data_type(event->tep, record);
  if (event->id == type) {
  /* do something */
  }
  into:
  if (tep_record_is_event(record, event)) {
  /* do something */
  }
  - tep_get_sub_buffer_commit_offset() - Add a function to return the
    offset of where the "commit" is located on the subbuffer
  so that the application can do its own direct reading of it.
  - kbuffer_read_buffer() - Add the functionality to the kbuffer to
  act like the read syscall of the ring buffer. That is, it
  will load the passed in buffer with the events where the
  kbuffer left off, and that passed in buffer can be loaded
  into another kbuffer via kbuffer_load_subbuffer().
  - kbuffer_dup() - Create a new kbuffer with the same fields of an
  existing kbuffer. This will allow traversing a subbuffer
  without modifying the contents of another kbuffer that
  points to the subbuffer.
  - kbuffer_subbuffer() - Return the subbuffer that was loaded into
  a kbuffer via kbuffer_load_subbuffer().
  - kbuffer_refresh() - In the case of the subbuffer that was loaded
  into a kbuffer via kbuffer_load_subbuffer() that is still
  active, this function will refresh the meta data to continue
  reading events if more were written to it.
  - Added tep_get_sub_buffer_data_size() helper function
  * Updates:
  - Add option to disable building documents for some environments
    that do not have everything needed to build the documents to
    not fail the build with meson.
  - Bump meson version required to build to 0.58.0 as plugins use
    str.replace that was introduced in that version.
  - Have the sched_switch plugin parse the format field to figure out
    what the correct mapping of the "prev_state" field is to produce
    the proper string output.
  * Fixes:
  - Update the default sched_switch "prev_state" string array to match
    what's been in the kernel for a while now.
  - Fix tep_kbuffer() to fill in the long_size, otherwise it would default
    to 32 bit longs and cause a lot of confusion to application developers
  - Fix tep_kbuffer man page info
  - Fix some meson dependency issues
  - Fix kbuffer_read_buffer() timestamp being off in some cases
  - Fix curr size in kbuffer_refresh()
* Thu Jun 15 2023 Tony Jones <tonyj@suse.com>
- Update to version 1.7.3
  * Handle printf '%%+d" case
  * Add initial support for meson
  * Handle %%c
- Drop patch 0001-libtraceevent-Add-initial-support-for-meson.patch (upstream)
* Thu Apr 27 2023 Dirk Müller <dmueller@suse.com>
- update to 1.7.2:
  * Fix some missing commas in big endian blocks
  * Rename "ok" to "token_has_paren" in process_sizeof()
  * No need for testing ok in else if (!ok) in process_sizeof()
  * Fix double free in parsing sizeof()
* Sat Feb 11 2023 Hans-Peter Jansen <hp@urpla.net>
- Let's build this package in %%build, not %%prep, as usual
- Link explicitly with -ldl allows building with older toolchains
* Tue Feb  7 2023 Daniel Wagner <daniel.wagner@suse.com>
- Sync meson build patch with latest upstream version
  * Documentation is build via extra build target
* Wed Jan 18 2023 Dirk Müller <dmueller@suse.com>
- update to 1.7.1:
  * Make sure 32 bit work on 64 bit file systems
  * Fix string parsing
  * Remove tep_find_function{address}() from libtraceevent
  * Fix output of raw prints
  * Show migrate-disabled field
* Sat Dec 24 2022 Daniel Wagner <daniel.wagner@suse.com>
- Update to release 1.7.0
  - New APIs:
    tep_find_function_info() - Returns not only the name of a function from its
    address, but also where the function starts and
  its size.
    tep_kbuffer() - Returns the kbuffer parser for a tep handle.
  - Now handles cpumask() macro parsing.
  - Add SAME_AS_HOST for endian and long size to kbuffer_alloc()
  - Handle dynamic fields that are not arrays.
  - Allow function parameters to have operators.
  - sizeof() parsing for some basic types.
  - Added man pages for the kbuffer API.
  - print_field_raw() terminates with '\0'
  - Fix uninitialized variables
  - Fix a "check after derer" coverity flaw
  - Fix testing the dereference pointer instead of the pointer for NULL.
  - Fix double free
- Build project with Meson
  * add 0001-libtraceevent-Add-initial-support-for-meson.patch
* Mon Aug 29 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release 1.6.2
  * Add API tep_get_function_count()
  * Reset right arg when copying TEP_PRINT_OP
  * Reset field properly in event_read_fields()
  * Fix memleak in make_bprint_args()
  * Add processing of __get_sockaddr() and __get_sockaddr_rel()
* Tue Apr  5 2022 Daniel Wagner <daniel.wagner@suse.com>
- Update to latest upstream version (1.5.3)
  Most notable changes are all bugfixes, e.g.:
  * Optimize constant logic in print format processing
  * Better parsing of fields with typecasts
  * Fix backward compatibility with tep_print_arg_string
  * Log printing updates
  * Fix man pages
  * Sample program to simplify testing of event format parsing
  * Better message of expected tokens
  * Fix parsing print fmts with new lines
  For details, see:
  * https://git.kernel.org/pub/scm/libs/libtrace/libtraceevent.git/tag/?h=libtraceevent-1.5.3
  * https://git.kernel.org/pub/scm/libs/libtrace/libtraceevent.git/tag/?h=libtraceevent-1.5.2
  * https://git.kernel.org/pub/scm/libs/libtrace/libtraceevent.git/tag/?h=libtraceevent-1.5.1
* Thu Feb 24 2022 Andreas Schwab <schwab@suse.de>
- Use %%{optflags}
- Makefile is not parallel-safe
* Tue Feb 22 2022 olaf@aepfle.de
- Force correct pkgconfig_dir location to fix build
* Wed Jan 19 2022 Dario Faggioli <dfaggioli@suse.com>
- Update to latest upstream version (1.5.0)
- Update romlintrc (again) to silence complains about plugins
* Fri May 14 2021 Tony Jones <tonyj@suse.com>
- Update rpmlintrc to suppress warnings about plugins
* Fri May 14 2021 Dario Faggioli <dfaggioli@suse.com>
- Update to latest upstream version (1.3.0)
* Wed May 12 2021 Tony Jones <tonyj@suse.com>
- Make package compliant with SLPP.
  Package plugins into so-ver specific directory.
* Fri May  7 2021 Dario Faggioli <dfaggioli@suse.com>
- Update to latest upstream version (1.2.1)
- Fix one rpmlint warning
* Tue Dec 22 2020 Jan Engelhardt <jengelh@inai.de>
- Rectify License: fields to mirror the SPDX lines found in source
  and the object builds.
- Rectify Group: fields.
- Fix duplicate manpages.
- Rename rpmlintrc according to policy.
- Update to release 1.1.1
  * trace-cmd libtraceevent: Fix bprint '#' parsing
  * Man page for tep_add_plugin_path() API
  * Man page for libtraceevent debug APIs
* Tue Oct 20 2020 Tony Jones <tonyj@suse.com>
- Initial checkin of libtraceevent.
